bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 4. Aventiure
___________________________________________________ #### Auentv wie Sivrit mit den Sahsen streit
| ### Do> chomen vremdiv mære in Guntheres lant ### von boten die im verre warn dar gesant ### von vnchvnden rechken die in trugen haz ### do si die rede vernamen leit was in innekliche daz
###### 141 | ### Die wil ich iv nennen ez was Lvdeger ### vzer Sahsen lande ein richer furste her ### vn– ovch von Tenemarche der kunic Lvdegast ### an dem sinen vriunden ganzer helfe nie gebrast
###### 142 | ### Ir boten chomen warn in Buregonden lant ### die ir widerwinnen heten dar gesant ### do vragte man der mære die unchvnden man ### do braht man si balde ze hofe fvr den kvnic stan
| ### Do sprach der kunic Gunther nv sit willekomen ### wer ivch her habe gesendet des enhan ich niht vernomen ### daz svlt ir lazen horen sprach der ritter gvot ### do vorhten si vil sere den grimmen Guntheres mvot
###### 144 | ### Welt ir uns kvnic erlovben daz wir iv mære sagen ### div wir iv da bringen sone svln wir niht verdagen ### wir nennen iv die herren die vns here habent gesant ### Livdegast vn– Livdeger die wellent svchen iwer lant
###### 145 | ### Ir habt ir haz verdienet ir svlt gelovben daz ### daz iv die rechen beide tragent grozen haz ### si wellent herverten ze Wormze an den Rin ### in hilfet vil der degene des sult ir ane zwifel sin
###### 146 | ### Inre zwelf wochen ir reise sol geschehen ### habt ir iemen vrivnde daz lat vil balde sehen ### die iv vriden hel[6v]fen die <burge> vn– iwer lant ### hie wirt von in verhowen vil manic herlicher rant
###### 147 | ### Oder welt ir mit in dingen so enbietet ez in dar ### sone ritent iv so nahen niht die starchen schar ### ze Wormez zv dem Rine vf hercenlichiv leit ### da von verderben mvzen die gvten ritter gemeit
| ### Nv bitet eine wile sprach kunic gvot ### vnz ich mih baz versinne ich kund iv minen mvot ### han ich getriwer iemen die sol ich niht verdagn ### disiv starchen mære sol ich minen friwenden sagen
###### 149 | ### Dem kunige disiv mære warn leide genvoc ### die rede er tovgenliche in sime hercen trvoc ### er hiez gewinnen Hagenen vn– ander sine man ### vn– bat ovch harte balde ze hofe nach Gernote gan
###### 150 | ### Do chomen im die besten swaz man der da vant ### er sprach man wil uns svochen her in unser lant ### mit starchen herverten daz lat iv wesen leit ### ez ist gar ane schvlde daz si uns habent widerseit
###### 151 | ### Daz wern wir mit swerten sprach do Gernot ### da sterbent wan die veigen die mvzen ligen tot ### dar vmbe ich niht vergezzen mac der eren min ### die unser widerwinnen suln vns willechomen sin
| ### Do sprach der starche Hagene daz endunchet mich niht gvot ### Livdegast un– Livdeger die tragent vbermvot ### wir mvgen uns niht besendet in so churzen tagen ### so sprach der chune reche wan mvget irz Sifride sagen
###### 153 | ### Die boten herbergen hiez man in die stat ### swie uient man in wære doch schone ir pflegen bat ### Gunther der riche daz was wolgetan ### vnz er eruant an <vriunden> wer im wolde gestan
###### 154 | ### Dem kunige in sinen sorgen was iedoch vil leit ### do sach in truorende ein degen vil gemeit ### der niht wizzen kunde waz im was geschehen ### do bat er im der mære den kunic Gunther veriehen
###### 155 | ### Mich wndert harte sere sprach do Siurit ### wie habt ir so verkeret die vroliche sit ### der ir nv mit uns lange habt alher gepflegen ### des antwrt im do Gunther der vil zierlich degen
###### 156 | ### Iane mag ich allen luten die swere niht gesagen ### die ich mvz tovgenliche in mime hercen tragen ### man sol stæten friunden chlagen hercen not ### div Sifrides varwe wart beidiv bleich vn– rot
| ### Er sprach zv dem kunige habt vf minen eit ### ich sol iv helfen wenden elliv iweriv leit ### welt ir vriunde svochen der sol ich einer sin ### vn– trowe ez wol mit eren volbringen an daz ende min
###### 158 | ### Nv lone iv got her Sivrit div rede mich dunchet gvot ### vn– ob mir nimmer helfe iwer ellen getvot ### ich frewe mich doch der mære daz ir mir sit so holt ### lebe ich deheine wile ez sol werden wol verscholt
###### 159 | ### Ich wil ivch lazen horen warvmbe ich trurich stan ### von boten miner viende ich daz vernomen han ### daz si mich svchen wellen mit heruerten [7r]hie ### daz getaten uns noch degene her zv disen landen nie
###### 160 | ### Daz lat ivch ahten ringe sprach do Sivrit ### vn– senftet iwerm mvote tvot des ich ivch bite ### lat mich iv erwerben ere vn– ovch den frumen ### e daz iwer uiende her ze disen landen chvmen
| ### Swenne iwer starche uiende zir helfe mohten han ### drizzech tusint degene so wol ich si bestan ### het ich niwan tusint des lat ivch an mich ### do sprach der kunic Gunther daz dien ich immer vmbe dich
###### 162 | ### So heizet mir gewinnen tusint iwerr man ### sit daz ich der minen bi mir niht enhan ### niwan zwelf degene so wer ich iwer lant ### iv sol immer dienen mit triwen Sifrides hant
###### 163 | ### Des sol uns helfen Hagene vn– ovch Ortwin ### <Danchwart> vn– Sindolt die lieben rechen din ### ovch sol da mit riten Volcher der kune man ### der sol den vanen fvren baz ihs nieman <engan>
###### 164 | ### Nv lat die boten riten wider in ir lant ### daz si uns da sehen schiere <daz> tv man in bekant ### so daz unser burge vride mvzen han ### do hiez der kunic besenden beidiv mage vn– man
###### 165 | ### Die boten Livdegeres ze hove giengen do ### daz si ze lande solden des warn si vil vro ### do bot in riche gabe Gunther der kunic gvot ### vn– schuf inn sin geleite des stunt in hohe der mvot
| ### Nv saget sprach do Gunther den vianden min ### si mugin mit ir reise wol da heime sin ### wellent aber si mich svochen her in miniv lant ### mirn zerinne miner frivnden in wirdet arbeit erchant
###### 167 | ### Den boten riche gabe man do fvr truoch ### der het in ze gebene der riche chunic genvoch ### dine torsten niht versprechen die Ludegeres man ### vrlovp si do namen vn– furen vrolichen dan
###### 168 | ### Do die boten waren ze <Tenemarchen> komen ### vn– der kunich Livdegast hete daz vernomen ### waz si ze Rine redeten als im daz wart geseit ### ir starchez vbermveten was im ane maze leit
###### 169 | ### Man saget im daz si heten manigen chunen man ### dar vnder sach man einen vor Gunthere stan ### der was geheizen Sifrit ein helt vz Niderlant ### ez leidete Livdegaste do er div mære reht ervarnt
| ### Do die von Tenemarche dizze horten sagen ### do ilten si der helfe deste me begagen ### so daz der kunic Livdegast siner mage un– man ### wol zweinzich tusint degene zv der reise gewan
###### 171 | ### Do besande ovch sich von Sahsen der chvne Livdeger ### vnz si vierzech tvsint heten vn– mer ### mit den si wolden riten in Guntheres lant ### do heten ovch sich hie heime die drie kunige besant
###### 172 | ### <mit> den Buregonden vn– ander <ir> <hohen> man ### die si durch vrlivge furen wolden dan ### si ilten sich bereiten des gie den helden not ### dar vnder mvsin degene side chiesen den tot
###### 173 | ### Si vlizzen sich zer reise do si wolden dane ### Volker dem chunen bevolhen wart der vane ### do si varen wolden ze Wormze vber Rin ### Hagene der star[7v]che der mvos scharmeister sin
###### 174 | ### Da mit reit ovch Sindolt vn– Hvnolt ### die wol gedienen chunden richer kunige golt ### Dancwart der snelle vn– ovch Ortewin ### die mohten wol mit eren in der heruerte sin
| ### <Her> kunic sit hie heime sprach do Sivrit ### sit daz iwer rechen mir wellen volgen mit ### belibet bi den frowen vn– habet hohen mvot ### ich trwoe iv wol beherten beidiv ere un– gvot
###### 176 | ### Die ivch da wolden svchen ze Wormze an den Rin ### daz sol ich wol behuten daz si iv iht schade sin ### wir svlen in geriten so nahen in ir lant ### daz in ir vbermveten werde in sorgen erwant
###### 177 | ### Von Rine si durch Hessen mit ir helden riten ### gegen der Sahsen lande da wart sit gestriten ### mit rvobe vn– ovch mit brande wosten si daz lant ### daz iz den fursten beiden wart mit arbeit bechant
| ### Si komen vf die marche die knehte zogeten dan ### Sifrit der vil starche vragen do began ### wer sol des gesindes vns nv hvten hie ### iane wart den Sahsen geriten schedelicher nie
###### 179 | ### Si sprachen lat der tumben huten vf den wegn ### den vil chunen marschalch der ist ein sneller degen ### wir verliesen deste minre von Livdegeres man ### lat in vn– Ortwinen hie die nachhvte han
###### 180 | ### So wil ich selbe riten sprach Siurit der degen ### vn– wil der warte gein den uienden pflegen ### vnz ich vil rehte ervinde wa die rechen sint ### do wart gewaffent balde der schonen Sigelinde kint
###### 181 | ### Daz volch bevalh er Hagene da er wolde dan ### vn– ovch Gernote dem uil kunem man ### do reit er eine dannen in der Sahsen lant ### da er div rehten mære wol mit eren sit ervant
###### 182 | ### Do sah er here daz grozze daz uf dem velde lac ### daz wider siner helfe mit vnfvge wach ### des was wol vierzech tusint oder dannoch baz ### der helt in hohem mvte sach vil frolichen daz
| ### Do het ovch sich ein reche von den vienden dar ### erhaben vf die warte der was ze vlize gar ### den sach der herre Sifrit vn– in der chune man ### ietweder do des andern mit nide govmen began
###### 184 | ### Ich sage iv wer der wære der hie der warte pflach ### ein liehter schilt von golde im vor der hende lach ### ez was der kunich Livdegast der hute siner schar ### dirre gast vil edele ernante vil herlichen dar
###### 185 | ### Nv hete ovch in her Livdegast vientlich erchorn ### ir ross si namen beide zen siten mit den sporn ### si neigten vf die schilde die schefte mit ir kraft ### des wart der kunic here mit grozen sorgen behaft
###### 186 | ### Div ross nach stiche trvgen div richen kuniges kint ### mit hurte fur ein ander sam si wæte ein wint ### mit zovmen wart gewendet vil ritterlichen dan ### mit swerten ez ersvhten die <zwen> grimme starche man
| ### Do sluch der herre Sifrit daz al daz velt erdoz ### do stovp im vz dem helme sam von brenden groz ### die heizen fivres vunchen [8r]von des rechen hant ### da streit vil mæhteklichen der voget vz Niderlant
###### 188 | ### Do sluoc ovch im her Livdegast vil manigen grimmen slach ### ir ietwederes ellen vf schilden vaste lach ### do heten dar gehutet wol drizzech siner man ### ê im der helfe chome den sich doch Sivrit gewan
###### 189 | ### mit drin starchen wnden die er dem kunige sluoc ### durch eine liehte brunne div was gvot genvoch ### daz swert an sinen ekken braht vz wnden bluot ### des gewan der kunic Livdegast einen trurigen mvot
###### 190 | ### Er bat sich leben lazen vn– bot im siniv lant ### vn– sagt im daz er wære Livdegast genant ### do chomen sine rechen die heten wol gesehen ### waz da von in beiden vf der warte was geschehen
| ### Do er in danne furte do ward er an gerant ### von drizzech sinen mannen do wert des heledes hant ### sinen richen gisel mit vngefugen slegen ### sit tet schaden mere Sifrit der vz erwelte degen
###### 192 | ### Die drizzech er ze tode vil werliche slvoch ### er liez ir leben einen balde er reit genvoch ### vn– sagt hin div mære waz hie was geschehn ### ovch moht mans die warheit an sinem rotem helme sehn
###### 193 | ### Den von Tenemarche was vil grimme leit ### ir herre was gevangen do in daz wart geseit ### man seit ez Livdegere toben er began ### von ungefugem zorne wand im was leide getan
###### 194 | ### Livdegast der riche was gefuret dan ### von Sifrides gewalte zv Guntheres man ### er bevalh in Hagene der chune reche guot ### do er vernam div mære do ward er frolich gemvot
| ### Er hiez der Burgonden ir vanen binden an ### wol vf so sprach Sivrit hie wirt noch me getan ### ê sich der tac verende sol ich habn den lip ### daz mvet in Sahsen lande etliches guten rechen wip
###### 196 | ### Ir helde von dem Rine ir sult min nemen war ### ich kan ivch wol geleiten in Livdegeres schar ### da seht helme howen von guter helede hant ### ê daz wir wider <wenden> in der Burgonden lant
###### 197 | ### Zen rossen gahte Gernot vn– ovch sine man ### Volker der chune den vanen zvochte dan ### der starche videlære do reit er vor der schar ### do was ovch daz gesinde ze strite herlichen gar
###### 198 | ### Sine furten doch niht mere niwan tusint man ### darvber zwelf rechen stieben do began ### div molte von den strazen si riten vber lant ### do sach man von in schinen vil manigen herlichen rant
| ### Do waren ovch die Sahsen mit ir <scharn> chomen ### mit swerten wol gewahsen als wir han sit vernomen ### div swert div sniten sere den rechen an der hant ### do wolden si den gesten wern burge vn– lant
###### 200 | ### Der herren scharmeister daz volch do furten dan ### da was ovch chomen Sifrit mit den sinen man ### die er da mit im brahte vzer Niderlant ### des tages wart in sturme vil manic blutiger rant
###### 201 | ### Sindolt vn– Hvnolt vn– ovch Ger[8v]not ### die vrumten in dem strite vil manigen helt tot ### e si daz reht erfunden wie chune was ir lip ### daz mvse sit beweinen vil manic wetlichez wip
###### 202 | ### Volker vn– Hagene vn– ovch Ortwin ### die lascten im strite vil maniges helmes schin ### mit vliezendem bluote ez warn chune man ### da wart von Danchwarte vil michel wnder getan
###### 203 | ### Die von Tenemarche versvohten wol ir hant ### do horte man von hurte erdiezen manigen rant ### vn– ovch von scharfpen swerten der man da vil gesluoc ### die stritchunen Sahsen taten scaden ovch genvoch
| ### Do die von Burgonden drungen in den strit ### von in wart verhowen vil manic wnde wit ### do sahe man vber sætele vliezen daz bluot ### svs wrben nach den eren die ritter chun vnde gvot
###### 205 | ### Man horte da luot erhellen den helden an der hant ### div vil scharpfen wafen da die von Niderlant ### drungen nach ir herren in die herten schar ### si chomen degenliche mit samt Sifride dar
###### 206 | ### Volgen der von Rine niemen man im sach ### man mohte chiesen vliezen den blvtigen bach ### durch die vil liehten helme von Sifrides hant ### vnz er Livdegeren von sinen hergesellen vant
###### 207 | ### Drie widerchere het er nv genomen ### des hers an ein ende nv was ovch Hagene chomen ### der half im wol ervollen in strite sinnen mvot ### des tages mvse ersterben von in vil manic ritter gvot
###### 208 | ### Do der starche Livdeger Sifriden vant ### vn– daz er so hohe trvge an siner hant ### daz vil scharpfe wafen vn– ir so manigen sluoc ### dar vmbe wart der chvene vor leide zornich genvoc
| ### Do wart ein michel dringen vn– groz der swerte klanch ### do ir ingesinde zv zein ander dranch ### do versuhten sich die rechen beidenthalben baz ### die schar begunden wichen sich huop da grozlicher haz
###### 210 | ### Dem vogete von den Sahsen was daz wol geseit ### sin bruder was gevangen daz was im harte leit ### wol wesser daz iz tete daz Sigelinde kint ### man zeh is Gernoten vil wol ervant er iz sint
###### 211 | ### Die slege Livdegeres die warn also starch ### daz im vnder satele struchte daz march ### do sich daz ross erholte der chune Siurit ### gewan in dem sturme einen vreiselichen sit
###### 212 | ### Des half im wol Hagene vn– ovch Gernot ### Ortwin vn– Volker des lage ir vil da tot ### Sindolt vn– Hunolt die zwene chune man ### von den vil manic frowe schaden grozzen da gewan
###### 213 | ### In sturme <vngescheiden> warn die kunige her ### do sah man vber helme vliegen manigen ger ### durch die liehten schilde von der degene hant ### man sach da var nach bluote manigen herlichen rant
| ### In dem starchen sturme erbeizte manic man ### nider von den rossen ein ander liefen an ### Sifrit der chune vn– ovch Livdeger ### da striten wol nach eren die helede chun vn– her
###### 215 | ### Do flovch [9r]daz schilt gespenge von Sifrides hant ### den sige gedaht erwerben der helt von Niderlant ### an den kunen Sahsen die dolten vngemach ### hei waz da liehter ringe der snelle Dancwart zebrach
###### 216 | ### Do het der herre Livdeger vf eime schilde erkant ### gemalet eine chrone vor Sifrides hant ### wol wesser daz iz wære der vbermvete man ### der helt zv sinen friunden starche rufen began
###### 217 | ### Gelovbet ivch des sturmes mage vn– man ### svn den Sigemundes ich hie gesehn han ### von Niderlant den starchen han ich hie bechant ### in hat der ubil tivfel her zen Sahsen gesant
###### 218 | ### Die vanen wrden lazen inn dem sturme nider ### frides er do gerte des wert man sider ### doch mvser werden gisel in Guntheres lant ### daz het an im ertwngen des chunen Sifrides hant
| ### Mit gemeinen rate so liezen si den strit ### durchel vil der helme vn– ovch der schilde wit ### si leiten von den handen swaz so man der vant ### die trugen blutes varwe von der Buregonden lant
###### 220 | ### Si viengen swen si wolden des heten si gewalt ### Gernot der herre vn– Hagene ein degen balt ### die wnden hiezen baren si furten mit in dan ### zv den Buregonden funf hundert wetlicher man
###### 221 | ### Die sigelosen rechen ze Tenemarchen riten ### do enheten ovch die Sahsen so hohe niht gestriten ### daz man in lobes iæhe daz was den heleden leit ### do wrden ovch die veigen von friunden sere gekleit
###### 222 | ### Si hiezen daz gewæfen wider sovmen an den Rin ### ez hete wol geworben mit den rechen sin ### Sifrit der starche het ez gvot getan ### dez im do iehen mvsen alle Guntheres man
| ### Gegen Wormez sande der herre Gernot ### heime zv sime lande den friunden er enbot ### wie im gelunge wære vnt den sinen man ### ez heten die vil chunen wol nach eren getan
###### 224 | ### Die garzvne liefen von den wart ez geseit ### do frevten sich die schoenen die ê heten leit ### der vil lieben mære die in waren chomen ### da wart von edeln frowen uil michel fragen vernomen
###### 225 | ### <wie> gelunge wære des richen chuniges man ### man hiez der boten einen zv Chriemh' gan ### daz geschach vil tovgen iane torstes vberlvot ### wan si hete dar vnder ir vil liebez hercen trvot
###### 226 | ### Do si den boten kvomenden zir kemenaten sach ### Chriemh' div uil schone gvtlichen sprach ### sag an liebiv mære ia gib ich dir min golt ### tvstvz ane triegen ih wil dir immer wesn holt
###### 227 | ### Wie schiet vz dem strite min bruder Gernot ### vn– ander mine friwende ist mir iht maniger tot ### wer tet da daz beste daz soltv mir sagen ### do sprach der bote biderbe wir heten ninder deheinen zagen
| ### Ze vorderst am striten reit niemen alse wol ### vil edeliv kuniginne sit manz iv sagen sol ### so der gast vil chune vzer Niderlant ### da worhte [9v]michel wnder des herren Sivrides hant
###### 229 | ### Swaz die rechen alle in strite hant getan ### Danchwart vn– Hagene vn– ander des kuniges man ### swaz iemen streit nach eren daz ist gar ein wint ### wider Sifriden des kunic Sigemundes kint
###### 230 | ### Si frumten in dem stvrme der helde vil erslagen ### doch enkund iv daz wnder niemen wol gesagen ### waz da worhte Sifrit swenner ze sturme reit ### den vrowen an ir magen frvmet er div groezlichen leit
###### 231 | ### Ovch mvste da beliben vil maniges wibes trvot ### sine slege man horte vf helmen alse luot ### daz si von wnden brahten daz vliezende blvot ### er ist in allen tugenden ein ritter kvn vn– gvot
###### 232 | ### Da hat ovch vil begangen von Mezzen Ortewin ### swaz er ir mohte erlangen mit den handen sin ### die mvsen wnt beliben oder meistich tot ### da tet iwer bruder die aller grozisten not
###### 233 | ### div immer in den stuormen chvnde sin geschehn ### man mvz der warheite den vzerwelten iehn ### die stolzen Burgonden die habent so gevarn ### daz si vor allen schanden ir ere chunnen wol bewarn
| ### Man sach da vor ir handen vil manigen satel bloz ### da von den liehten swerten daz velt vil lvt erdoz ### die rechen von dem Rine die habent so gestriten ### daz ez ir vianden wære bezzer vermiten
###### 235 | ### Die chunen Tronegære die taten groziv leit ### da man mit volches chreften zv zein ander reit ### da vrumte manigen toten des chunen Hagenen hant ### des vil ze sagene wære her zer Burgonden lant
###### 236 | ### Sindolt vn– Hunolt die Gernotes man ### vn– Rvmolt der vil chune die hantz so gvot getan ### daz er Livdegere mac immer wesn leit ### daz er den minen herren het ze Rine widerseit
###### 237 | ### Strit den aller hohsten der inder da geschach ### ze iungest vn– zem ersten den ieman gesach ### den tet vil willekliche div Sifrides hant ### er bringet riche gisel in daz Guntheres lant
###### 238 | ### Die twanc mit sinen ellen der wætlich man ### des ovch der kunic Livdegast schaden vil gewan ### vn– ovch von den Sahsen der chune Livdeger ### nv horet miniv mære vil edeliv kuniginne her
| ### Si hat gevangen beide div Sifrides hant ### ez enwart nie meniger gisel braht in dizze lant ### so nv von sinen schulden chumet an den Rin ### ir enchunden disiv mære nimmer lieber gesin
###### 240 | ### Man bringet der gesunden fvnf hvndert oder baz ### vn– der verchwnden frowe wizzet daz ### wol ahzech roze bære in Burgonden lant ### die meistech hat verhowen des chunen Sifrides hant
###### 241 | ### Die durch ir vbermveten widersageten an den Rin ### die mvzen nv gevangen die Guntheres sin ### die bringet man mit frevden her in dizze lant ### do erblvet ir liehtiv varwe do si div mære reht ervant
###### 242 | ### Ez wart ir lieth antlvzze vor liebe rosen rot ### do mit [10r]liebe was gescheiden vz der grozen not ### der minneklich reche Sivrit der iunge man ### si vrevt ovch sich ir friunde daz was von schulden getan
| ### Do sprach div minnekliche dv hast mir wol geseit ### dv solt haben dar vmbe ze miete richiv kleit ### vn– zehn march von golde heiz ich dir tragen ### des mag man solchiv mære richen frowen gern sagen
###### 244 | ### Man gab im sine miete daz golt vn– ovch div chleit ### do gie an div venster vil manic schoniv meit ### si warten vf die straze riten man do vant ### vil der hochgemvten in der Burgonden lant
###### 245 | ### Da chomen die gesunden die wnden taten sam ### si mohten grvzen horen von vriunden ane scham ### der wirt gein sinen gesten vil vrolichen reit ### mit vreuden was verendet daz sin vil grozliche leit
###### 246 | ### Do enpfie er wol die sine die vremden tet er sam ### wan dem richen kunige anders niht enzam ### wan danchen gvetliche die im warn chomen ### daz si den sige nach eren in stvrme heten genomen
| ### Gvnther bat <im> mere von sinen frivnden sagen ### wer im an der reise ze tode wær irslagen ### do het er vlorn niem niwan sehzech man ### verklagen man die mvse so sit nach heleden ist getan
###### 248 | ### Di gesunden brahten verhowen manigen rant ### vn– helme vil verschroten in Guntheres lant ### si stunden von den rossen nider fur den sal ### ze liebem antpfange man horte vrolichen schal
###### 249 | ### Do hiez man herbergen die wegemvden man ### der kunic sinen gesten danchen vil began ### er hiez der wnden hveten vn– schaffen in gemach ### wol man sine tvgende an sinen vianden sach
###### 250 | ### Er sprach ze Livdegere nv sit mir willechomen ### ich han von iwern schulden schaden vil genomen ### der wirt mir nv gebvzet ob ich gelucke han ### got lone minen frivnden si hant mir liebe getan
###### 251 | ### Ir mvgt in gerne danchen sprach do Livdegere ### also hoher gisel gewan nie kunic mere ### vmbe schone hvte wir bieten michel gvot ### daz ir genædechliche an mir vn– minen frivnden tvot
| ### Ich wil ivch ledech lazen sprach der kunic gen ### daz mine viande hie bi mir besten ### des wil ich haben burgen daz si miniv lant ### iht rvemen ane hulde des sichert do ir beder hant
###### 253 | ### Man brahte si ze rowe vn– schvf in gvt gemach ### den wnden man gebettet vil gvtlichen sach ### man schancte den gesunden met vn– gvten win ### do chunde daz gesinde nimmer vrolicher sin
###### 254 | ### Ir zerhowen schilde man behalten trvoch ### blvtiger sætele der was da genvoch ### die hiez man ovch verbergen daz weinten niht div wip ### do chom hermvede vil maniges chunen ritters lip
###### 255 | ### Der wirt pflac siner geste vil grozliche wol ### der vremden vn– der chunden was daz lant so vol ### man hiez der sere wnden vil gvtliche pflegn ### do was ir vbermveten vil harte ringe [10v]gelegn
###### 256 | ### Die ercznie chunden den bot man grozen scholt ### silber ane wage daz zvo daz liehte golt ### daz si die helde nerten nach des strites not ### dar zvo der kunic den gesten gabe grozlich bot
| ### Die wider heim ze hvse der reise heten mvot ### die bat noch beliben also man friunde tvot ### der kunic gie ze rate wier lonte sinen man ### si heten sinen willen nach grozen eren getan
###### 258 | ### Do sprach der herre Gernot man sol si riten lan ### vber sehs wochen si in daz chunt getan ### daz si chomen widere zeiner hochgecite ### so ist maniger geheilet der nv vil sere wnd lit
###### 259 | ### Do gert ovch vrlovbes der helt von Niderlant ### do der kunic Gvnther den willen sin ervant ### er bat in minnekliche noch bi im bestan ### wan durch Chriemhilde so wær ez nimmer getan
###### 260 | ### Dar zvo was er ze riche daz er iht næme solt ### er het daz wol verdienet der kunic was im holt ### sam waren sine mage die heten daz gesehn ### waz von sinem ellen in dem stvrme was geschehn
###### 261 | ### Durch der schonen willen gedaht noch bestan ### die er vil gern sehe sit wart ez getan ### al nach sinem mvote si warde im wol bechant ### sit reit er vroliche heim in sines vater lant
| ### Der wirt hiez zallen citen ritterschefte pflegn ### daz tet do willechliche vil manic iunger degn ### die wil hiez er sidelen vor Wormze an den sant ### den die im chomen solden zv den Burgonden lant
###### 263 | ### In den selben citen do si nv solden chomen ### do het div vrowe Chriemh' div mære wol vernomen ### er wolde hochgeciten mit magen vn– man ### do wart vil michil vlizen von schonen vrowen getan
###### 264 | ### mit wæte vn– mit gebende daz si solden tragen ### Vte div vil riche div mære horte sagn ### von den stolzen degenen die da solden chomen ### do wart vz der valde gvter wæte vil genomen
###### 265 | ### Durch ir kinde liebe hiez si do sniden kleit ### da mit wart gezieret vil frowen vn– manic meit ### vn– vil der iungen rechen vz Burgonden lant ### da wart ovch vil der vremden bereitet herlich gewant

<<< Übersicht <<< vorige Seite nächste Seite >>>